==> em_tasks-0.1.17-py2.py3-none-any.whl: em_tasks/tasks/shopify_task.py <==
import json

from em_tasks import logger
from em_tasks.shopify.product_util import ProductUtil
from em_tasks.store.store_util import StoreUtil
from em_tasks.store.models import *


class ShopifyTask():
  def create_product(self, store_code, seller_id, prod):
    store = StoreUtil.get_store_by_code(store_code)
    if not store:
      return

    credential = json.loads(store.api_credential)
    product_util = ProductUtil(credential['name'], credential['token'], credential.get('release', None))
    product = product_util.create_product(prod)
    if not product:
      return

    try:
      gmc_product = GmcProduct.get_or_none(GmcProduct.handle == product.handle)
      if not gmc_product:
        gmc_prod_attrs = product_util.to_gmc_product(product)
        seller = StoreUtil.get_seller(seller_id)
        gmc_prod_attrs['externalSellerId'] = seller.code
        gs = StoreUtil.get_default_google_shopping_store()
        gs.upload_products([gmc_prod_attrs])
    except Exception as e:
      logger.exception(e)

    source = prod.get('source', None)
    source_product_id = prod.get('source_product_id', None)

    product_attrs = {
      's_product_id': product.id,
      'handle': product.handle,
      'title': product.title,
      'description': product.body_html,
      'has_image': bool(product.images)
    }
    StoreUtil.save_store_product(seller_id, source, source_product_id, product_attrs)

  def delete_product(self, store_code, product_id):
    store = StoreUtil.get_store_by_code(store_code)
    if not store:
      return

    credential = json.loads(store.api_credential)
    product_util = ProductUtil(credential['name'], credential['token'], credential.get('release', None))
    try:
      product_util.delete_product(product_id)
    except:
      pass

    try:
      StoreUtil.delete_store_product(product_id)
    except:
      pass

==> em_tasks-0.1.24-py2.py3-none-any.whl: em_tasks/tasks/shopify_task.py <==
import json

from em_tasks import logger
from em_tasks.shopify.product_util import ProductUtil
from em_tasks.store.store_util import StoreUtil
from em_tasks.store.models import *


class ShopifyTask():
  def create_product(self, store_code, seller_id, prod):
    store = StoreUtil.get_store_by_code(store_code)
    if not store:
      return

    credential = json.loads(store.api_credential)
    product_util = ProductUtil(credential['name'], credential['token'], credential.get('release', None))
    product = product_util.create_product(prod)
    if not product:
      return

    try:
      gmc_product = GmcProduct.get_or_none(GmcProduct.handle == product.handle)
      if not gmc_product:
        gmc_prod_attrs = product_util.to_gmc_product(product)
        seller = StoreUtil.get_seller(seller_id)
        if seller:
          gmc_prod_attrs['externalSellerId'] = seller.code
        else:
          gmc_prod_attrs['externalSellerId'] = 'em'
        gs = StoreUtil.get_default_google_shopping_store()
        gs.upload_products([gmc_prod_attrs])
    except Exception as e:
      logger.exception(e)

    source = prod.get('source', None)
    source_product_id = prod.get('source_product_id', prod.get('product_id', None))
    sku = None
    if 'sku' in prod and prod['sku']:
      sku = prod['sku']
    else:
      sku = product.variants[0].sku

    product_attrs = {
      's_product_id': product.id,
      'handle': product.handle,
      'sku': sku,
      'title': product.title,
      'description': product.body_html,
      'has_image': bool(product.images)
    }
    StoreUtil.save_store_product(seller_id, source, source_product_id, product_attrs)

  def delete_product(self, store_code, product_id):
    store = StoreUtil.get_store_by_code(store_code)
    if not store:
      return

    credential = json.loads(store.api_credential)
    product_util = ProductUtil(credential['name'], credential['token'], credential.get('release', None))
    try:
      product_util.delete_product(product_id)
    except:
      pass

    try:
      StoreUtil.delete_store_product(product_id)
    except:
      pass
